function [r,dx,n]= pontofixo(f,x0,dxd,kmax,L)
% Método do ponto fixo para raiz de f(x)=0
%
% [r,dx,n]= pontofixo(f,x0,dxd,kmax)
%
% f - referência para função f(x)
% x0 - estimativa inicial
% dxd - dx máximo desejado, dx=|x(k)-x(k-1)| - erro abosluto
% kmax - limite de iterações
% L - max |f'(x)|
%
% r - estimativa da raiz r=xn
% dx - (L/(1-L))*abs(x1-x0) - erro absoluto estimado
% n - índice da estimativa na sequência gerada x0,x1,...,xn

% file pontofixo.m

k=0;
x1=f(x0);
% calculo da estimativa do erro absoluto com formula 1.24
dx=(L/(1-L))*abs(x1-x0);

fprintf('\n------- Método do ponto fixo ------- dx<=%.2e\n',dxd)
fprintf('  k            xk             dx\n')
fprintf(' %2d  %20.15f\n',0,x0)
fprintf(' %2d  %20.15f  %9.2e\n',1,x1,dx)


while ( dx >dxd && k<kmax )% erro abs > 4 casas significativas
   x0=x1;
   x1=f(x0);
   dx=(L/(1-L))*abs(x1-x0); % actualização do erro abs estimado
   k=k+1;
   fprintf(' %2d  %20.15f  %9.2e\n',k+1,x1,dx)
end
r=x1;

n=k+1;
if dx>dxd
   fprintf('*** A precisão desejada não foi atingida! ***\n')
end

% EOF


